C
C
C     PROGRAM XSECT
C
      IMPLICIT NONE
C
C     XSECT - PROGRAM TO CONVERT CROSS SECTIONS FROM HSP-II FORMAT
C             TO HSPF FTABLE FORMAT, ENGLISH UNITS
C     VERSION 3 ADDED THE ABILITY TO ADJUST THE CHANNEL HEIGHT FOR 
C               INITIAL DEPTH GREATER THAN ZERO.  ALSO, TOTAL AREA FOR
C               FLOOD PLAIN AND INCISED CHANNEL WERE COMBINED FOR OUTPUT
C
C     *** FORTRAN FILE NUMBERS ***
C        INPUT  - UNIT 8, INPUT FILE
C        OUTPUT - UNIT 7, OUTPUT FILE
C
C     + + + LOCAL VARIABLES + + +
      INTEGER I1,I2,I3,RCHNUM,ROWS,INPUT,OUTPUT
      REAL    LENGTH,ELUP,ELDOWN,W1,W2,H,SFP,NCH,SLOPE,THETA1,WP1,
     1        THETA2,WP2,INC,DEPTH,TW,AREA,VOLUME,WETP,HYDRAD,DISCH,
     2        SFAREA,AREAIN,WETPIN,NFP,FLOTIM,NCH2,NCH3,NFP2,AREAC,
     3        AREAOB,AREAT,HYDRADC,HYDRADOB,HYDRADT,BKFH,IDEPTH
      CHARACTER*80 FILNAM
C
C     + + + DATA INITIALIZATIONS + + +
      DATA INPUT,OUTPUT/8,7/
C
C     + + + READ FORMATS + + +
1000  FORMAT(I5,9F8.0)
C
C     + + + WRITE FORMATS + + +
2000  FORMAT('  FTABLE    ',I4)
2010  FORMAT(I5,'    4')
2020  FORMAT(F10.3,F10.3,F10.2,F10.2,F10.1)
2030  FORMAT(' ROWS COLS ***')
2040  FORMAT('  END FTABLE',I4,/)
2050  FORMAT('     DEPTH      AREA    VOLUME     DISCH  FLO-THRU ***')
2060  FORMAT('      (FT)   (ACRES)   (AC-FT)     (CFS)     (MIN) ***')
2070  FORMAT('      .000      .000     .0000      .000       0.0')
2080  FORMAT(1X,'  RCH  LENGTH    ELUP    ELDN      W1      W2    BKFH',
     1          '     SFP     NCH     NFP',/)
2090  FORMAT(1X,I5,F8.3,2F8.1,2F8.1,F8.2,3F8.3)    
C
 3    CONTINUE
        WRITE (*,*) ' ENTER INPUT FILENAME: '
        READ (*,*) FILNAM
        OPEN (UNIT=INPUT,FILE=FILNAM,STATUS='OLD',ERR=3)
 5    CONTINUE
        WRITE (*,*) ' ENTER OUTPUT FILENAME: '
        READ (*,*) FILNAM
        OPEN (UNIT=OUTPUT,FILE=FILNAM,STATUS='UNKNOWN', ERR=5)
C
C     SEE BELOW FOR DEFINITIONS AND UNITS
      READ(INPUT,1000,END=60,ERR=60) RCHNUM,LENGTH,ELUP,ELDOWN,W1,W2,
     1                         BKFH,SFP,NCH,NFP
C
      IF (RCHNUM .LE. 0) GOTO 60
      WRITE(*,2080) 
      WRITE(*,2090) RCHNUM,LENGTH,ELUP,ELDOWN,W1,W2,BKFH,
     1                   SFP,NCH,NFP
C
C     LENGTH -     REACH LENGTH (MILES)
C     ELUP   -     UPSTREAM ELEVATION (FT)
C     ELDOWN -     DOWNSTREAM ELEVATION (FT)
C     W1     -     CHANNEL BOTTOM WIDTH (FT)
C     W2     -     CHANNEL BANKFULL WIDTH (FT)
C     BKFH   -     CHANNEL HEIGHT (FT)
C     SFP    -     SLOPE OF FLOOD PLAIN (-)
C     NCH    -     MANNINGS N FOR THE CHANNEL
C     NFP    -     MANNINGS N FOR THE FLOOD PLAIN
C
C     DOUNTIL END OF FILE
10    CONTINUE
        IDEPTH= 0.0 
        DEPTH = IDEPTH
        H     = BKFH - DEPTH
        INC   = H/12.0
        WRITE (OUTPUT,2000) RCHNUM
        WRITE (OUTPUT,2030)
        SLOPE  = ABS(ELUP-ELDOWN)/(LENGTH*5280.)
C       WRITE (TTYOUT,*) SLOPE,ELUP,ELDOWN,LENGTH
        THETA1 = ATAN((W2-W1)/(2.*H))
        WP1    = COS(THETA1)
        THETA2 = ATAN(SFP) 
        WP2    = SIN(THETA2)
C 
        ROWS= 19
        WRITE (OUTPUT,2010) ROWS 
        WRITE (OUTPUT,2050)
        WRITE (OUTPUT,2060)
        WRITE (OUTPUT,2070)
C 
C       MAIN CHANNEL COMPUTATIONS 
C 
        DO 40 I1 = 1,6
          DEPTH  = DEPTH + INC
          TW     = W1 + ((W2-W1)/H)*DEPTH 
          SFAREA = TW*LENGTH*5280./43560.
          AREA   = ((TW+W1)/2)*DEPTH 
          VOLUME = AREA*LENGTH*5280./43560.
          WETP   = W1 + 2*(DEPTH/WP1)
          HYDRAD = AREA/WETP
             IF(I1 .EQ. 1) THEN 
                 NCH2 = NCH*0.050 
             ENDIF
             IF(I1 .EQ. 2) THEN 
                 NCH2 = NCH*0.051 
             ENDIF
             IF(I1 .EQ. 3) THEN 
                 NCH2 = NCH*0.048 
             ENDIF
             IF(I1 .EQ. 4) THEN 
                 NCH2 = NCH*0.047 
             ENDIF
             IF(I1 .EQ. 5) THEN 
                 NCH2 = NCH*0.044
             ENDIF
             IF(I1 .EQ. 6) THEN 
                 NCH2 = NCH*0.041
             ENDIF
          DISCH  = 1.49*AREA*(HYDRAD**0.667)*(SLOPE**0.5)/NCH2
          FLOTIM = (VOLUME*43560.)/(DISCH*60.) 
c 3000     FORMAT (I3,5F8.3)
c          WRITE (*,*) ' LVL DEPTH  TOPWID XSAREA WETP HYDRAD'
c          WRITE (*,3000) I1,DEPTH,TW,AREA,WETP,HYDRAD
          WRITE (OUTPUT,2020) DEPTH,SFAREA,VOLUME,DISCH,FLOTIM
40      CONTINUE
C 
        INC  = 2.0*INC
        DO 42 I2 = 7,9
          DEPTH  = DEPTH+ INC 
          TW     = W1+ ((W2-W1)/H)*DEPTH 
          SFAREA = TW*LENGTH*5280./43560.
          AREA   = ((TW+W1)/2)*DEPTH 
          VOLUME = AREA*LENGTH*5280./43560.
          WETP   = W1+ 2*(DEPTH/WP1)
          HYDRAD = AREA/WETP 
             IF(I2 .EQ. 7) THEN 
                 NCH3 = NCH*0.039 
             ENDIF 
             IF(I2 .EQ. 8) THEN 
                 NCH3 = NCH*0.041
             ENDIF 
             IF(I2 .EQ. 9) THEN 
                 NCH3 = NCH*0.037  
             ENDIF 
          DISCH  = 1.49*AREA*(HYDRAD**0.667)*(SLOPE**0.5)/NCH3 
          FLOTIM = (VOLUME*43560.)/(DISCH*60.) 
c          WRITE (*,*) ' LVL DEPTH  TOPWID XSAREA WETP HYDRAD'
c          WRITE (*,3000) I2,DEPTH,TW,AREA,WETP,HYDRAD
          WRITE (OUTPUT,2020) DEPTH,SFAREA,VOLUME,DISCH,FLOTIM 
42      CONTINUE
C 
C       OVERBANK COMPUTATIONS 
C 
        AREAIN = ((W1+W2)/2)*H 
        WETPIN = W1+ 2*(H/WP1) 
        INC    = 2.0*INC
        DO 50 I3 = 10,18
          DEPTH  = DEPTH+ INC 
          TW     = W2+ 2*(DEPTH-H)/SFP 
          SFAREA = TW*LENGTH*5280./43560.
C 
C         INCISED CHANNEL 
          AREAC  = AREAIN+ W2*(DEPTH-H)
          VOLUME = AREAC*LENGTH*5280./43560.
          HYDRADC= AREAC/WETPIN 
c          WRITE (*,*) ' LVL DEPTH  TOPWID XSAREA WETP HYDRADC'
c          WRITE (*,3000) I3,DEPTH,TW,AREAC,WETPIN,HYDRADC
          DISCH  = 1.49*AREAC*(HYDRADC**0.667)*(SLOPE**0.5)/NCH3 
C 
C         OVERBANK
          AREAOB  = (DEPTH-H)*(DEPTH-H)/SFP 
          VOLUME  = VOLUME+ AREAOB*LENGTH*5280./43560.
          WETP    = 2*(DEPTH-H)/WP2 
          HYDRADOB= AREAOB/WETP
             IF(I2 .EQ. 10) THEN 
                 NFP2 = NFP*0.051  
             ENDIF 
             IF(I2 .EQ. 11) THEN 
                 NFP2 = NFP*0.056  
             ENDIF 
             IF(I2 .EQ. 12) THEN 
                 NFP2 = NFP*0.062  
             ENDIF 
             IF(I2 .EQ. 13) THEN 
                 NFP2 = NFP*0.075  
             ENDIF 
             IF(I2 .EQ. 14) THEN 
                 NFP2 = NFP*0.075
             ENDIF 
             IF(I2 .EQ. 15) THEN 
                 NFP2 = NFP*0.075
             ENDIF 
             IF(I2 .EQ. 16) THEN 
                 NFP2 = NFP*0.075
             ENDIF 
             IF(I2 .EQ. 17) THEN 
                 NFP2 = NFP*0.075
             ENDIF 
             IF(I2 .EQ. 18) THEN 
                 NFP2 = NFP*0.075
             ENDIF 
c          WRITE (*,*) ' LVL DEPTH  TOPWID XSAREA WETP HYDRADOB'
c          WRITE (*,3000) I3,DEPTH,TW,AREAOB,WETP,HYDRADOB
          DISCH  = DISCH+ 1.49*AREAOB*(HYDRADOB**0.667)*(SLOPE**0.5)/NFP2
C
          FLOTIM = (VOLUME*43560.)/(DISCH*60.)
          AREAT  = AREAC + AREAOB
          HYDRADT= HYDRADC + HYDRADOB
          WRITE (OUTPUT,2020) DEPTH,SFAREA,VOLUME,DISCH,FLOTIM
50      CONTINUE
C
        WRITE (OUTPUT,2040) RCHNUM
        READ (INPUT,1000,END=60) RCHNUM,LENGTH,ELUP,ELDOWN,W1,W2,
     1                           BKFH,SFP,NCH,NFP
        WRITE (*,2090) RCHNUM,LENGTH,ELUP,ELDOWN,W1,W2,
     1                     BKFH,SFP,NCH,NFP
C
      GO TO 10
C     ENDDO
C
60    CONTINUE
C
c
      END                                                               
